.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install swagger_stub

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv swagger_stub
    $ pip install swagger_stub
